<?php

namespace Litecms\Profile2\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Profile2\Models\Profile2;

class Profile2Policy
{

    /**
     * Determine if the given user can view the profile2.
     *
     * @param UserPolicy $user
     * @param Profile2 $profile2
     *
     * @return bool
     */
    public function view(UserPolicy $user, Profile2 $profile2)
    {
        if ($user->canDo('profile2.profile2.view') && $user->isAdmin()) {
            return true;
        }

        return $profile2->user_id == user_id() && $profile2->user_type == user_type();
    }

    /**
     * Determine if the given user can create a profile2.
     *
     * @param UserPolicy $user
     * @param Profile2 $profile2
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('profile2.profile2.create');
    }

    /**
     * Determine if the given user can update the given profile2.
     *
     * @param UserPolicy $user
     * @param Profile2 $profile2
     *
     * @return bool
     */
    public function update(UserPolicy $user, Profile2 $profile2)
    {
        if ($user->canDo('profile2.profile2.edit') && $user->isAdmin()) {
            return true;
        }

        return $profile2->user_id == user_id() && $profile2->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given profile2.
     *
     * @param UserPolicy $user
     * @param Profile2 $profile2
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Profile2 $profile2)
    {
        return $profile2->user_id == user_id() && $profile2->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given profile2.
     *
     * @param UserPolicy $user
     * @param Profile2 $profile2
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Profile2 $profile2)
    {
        if ($user->canDo('profile2.profile2.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given profile2.
     *
     * @param UserPolicy $user
     * @param Profile2 $profile2
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Profile2 $profile2)
    {
        if ($user->canDo('profile2.profile2.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
