<?php

namespace Litecms\Profile2\Providers;

use Illuminate\Support\ServiceProvider;

class Profile2ServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'profile2');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'profile2');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.profile2', function ($app) {
            return $this->app->make('Litecms\Profile2\Profile2');
        });

                // Bind Profile2 to repository
        $this->app->bind(
            'Litecms\Profile2\Interfaces\Profile2RepositoryInterface',
            \Litecms\Profile2\Repositories\Eloquent\Profile2Repository::class
        );

        $this->app->register(\Litecms\Profile2\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\Profile2\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.profile2'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/profile2.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/profile2')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/profile2')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
